==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d2/dcc/sdl__v_8cpp.js <==
var sdl__v_8cpp =
[
    [ "VkMapping", "db/d73/structVkMapping.html", "db/d73/structVkMapping" ],
    [ "AM", "d2/dcc/sdl__v_8cpp.html#a522071f391a5eced6ca3d88b3496a7c1", null ],
    [ "AS", "d2/dcc/sdl__v_8cpp.html#ac2c71e01479b0b511b71905fe0ce49de", null ],
    [ "MAX_DIRTY_RECTS", "d2/dcc/sdl__v_8cpp.html#a6846280e1d94145403171ed05a3601a4", null ],
    [ "CheckPaletteAnim", "d2/dcc/sdl__v_8cpp.html#ac2bbc0961c64af34880dbdf7b4b824d5", null ],
    [ "ConvertSdlKeyIntoMy", "d2/dcc/sdl__v_8cpp.html#ab7cc31b05a2c53102a42facc27bdf753", null ],
    [ "DrawSurfaceToScreen", "d2/dcc/sdl__v_8cpp.html#aa597dfddc38f2c28f3e08e8c184899ce", null ],
    [ "DrawSurfaceToScreenThread", "d2/dcc/sdl__v_8cpp.html#a20a8455741c6df78c1bb4dd2b07c10c0", null ],
    [ "GetAvailableVideoMode", "d2/dcc/sdl__v_8cpp.html#a2afd1ba8ddf1d97c80f81c9001d6ffd4", null ],
    [ "GetVideoModes", "d2/dcc/sdl__v_8cpp.html#a6c91326e52c7ca726c883fc5bd7d11f0", null ],
    [ "InitPalette", "d2/dcc/sdl__v_8cpp.html#a60390e709978e185b46460cbd9f8a285", null ],
    [ "UpdatePalette", "d2/dcc/sdl__v_8cpp.html#a51271b1cdf4cbf1e2142268154697a20", null ],
    [ "_all_modes", "d2/dcc/sdl__v_8cpp.html#ae97bbfba591e22d0a023ac15c75cf1be", null ],
    [ "_default_resolutions", "d2/dcc/sdl__v_8cpp.html#a90d70da243d2a7f7a08a41190f2dfaa2", null ],
    [ "_dirty_rects", "d2/dcc/sdl__v_8cpp.html#a86daf288a82ad56f139e2ee5e40d26af", null ],
    [ "_draw_continue", "d2/dcc/sdl__v_8cpp.html#a83b7c91807a94e09901c50386a6ca90c", null ],
    [ "_draw_mutex", "d2/dcc/sdl__v_8cpp.html#a53b7002dbbd95a5d36d58908f35e2055", null ],
    [ "_draw_thread", "d2/dcc/sdl__v_8cpp.html#a5b88b5bb0b2e5c390c2cfbc73b525c81", null ],
    [ "_draw_threaded", "d2/dcc/sdl__v_8cpp.html#ac44f053e1e70a94bbe88cf6f973a3095", null ],
    [ "_local_palette", "d2/dcc/sdl__v_8cpp.html#a202ff6c8b1a11ccdc59df0dba543cdd5", null ],
    [ "_num_dirty_rects", "d2/dcc/sdl__v_8cpp.html#a1f9389b682678b0bed1eb3763ba164eb", null ],
    [ "_requested_hwpalette", "d2/dcc/sdl__v_8cpp.html#a311728b0d04dd857a5ffe58e9b830f98", null ],
    [ "_sdl_realscreen", "d2/dcc/sdl__v_8cpp.html#a9d1993f5034604c0523dd4552b7428dd", null ],
    [ "_sdl_screen", "d2/dcc/sdl__v_8cpp.html#afe19d6a18800bc7ab1a76c5060706d8f", null ],
    [ "_use_hwpalette", "d2/dcc/sdl__v_8cpp.html#a4cfdca600f2c56e6eb8dbdc60996374e", null ],
    [ "_vk_mapping", "d2/dcc/sdl__v_8cpp.html#aaa6910b0fdef2ce9c5578cba4112f711", null ],
    [ "iFVideoDriver_SDL", "d2/dcc/sdl__v_8cpp.html#a343bfdc6c576594d2d2bcac975def6ab", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d2/dcc/sdl__v_8cpp.js <==
var sdl__v_8cpp =
[
    [ "VkMapping", "db/d73/structVkMapping.html", "db/d73/structVkMapping" ],
    [ "AM", "d2/dcc/sdl__v_8cpp.html#a522071f391a5eced6ca3d88b3496a7c1", null ],
    [ "AS", "d2/dcc/sdl__v_8cpp.html#ac2c71e01479b0b511b71905fe0ce49de", null ],
    [ "MAX_DIRTY_RECTS", "d2/dcc/sdl__v_8cpp.html#a6846280e1d94145403171ed05a3601a4", null ],
    [ "CheckPaletteAnim", "d2/dcc/sdl__v_8cpp.html#ac2bbc0961c64af34880dbdf7b4b824d5", null ],
    [ "ConvertSdlKeyIntoMy", "d2/dcc/sdl__v_8cpp.html#ab7cc31b05a2c53102a42facc27bdf753", null ],
    [ "DrawSurfaceToScreen", "d2/dcc/sdl__v_8cpp.html#aa597dfddc38f2c28f3e08e8c184899ce", null ],
    [ "DrawSurfaceToScreenThread", "d2/dcc/sdl__v_8cpp.html#a7a612632187bbff242dcb8890eb16340", null ],
    [ "GetAvailableVideoMode", "d2/dcc/sdl__v_8cpp.html#a2afd1ba8ddf1d97c80f81c9001d6ffd4", null ],
    [ "GetVideoModes", "d2/dcc/sdl__v_8cpp.html#a6c91326e52c7ca726c883fc5bd7d11f0", null ],
    [ "InitPalette", "d2/dcc/sdl__v_8cpp.html#a60390e709978e185b46460cbd9f8a285", null ],
    [ "UpdatePalette", "d2/dcc/sdl__v_8cpp.html#a51271b1cdf4cbf1e2142268154697a20", null ],
    [ "_all_modes", "d2/dcc/sdl__v_8cpp.html#ae97bbfba591e22d0a023ac15c75cf1be", null ],
    [ "_default_resolutions", "d2/dcc/sdl__v_8cpp.html#a90d70da243d2a7f7a08a41190f2dfaa2", null ],
    [ "_dirty_rects", "d2/dcc/sdl__v_8cpp.html#a86daf288a82ad56f139e2ee5e40d26af", null ],
    [ "_draw_continue", "d2/dcc/sdl__v_8cpp.html#a83b7c91807a94e09901c50386a6ca90c", null ],
    [ "_draw_mutex", "d2/dcc/sdl__v_8cpp.html#af24370c5565125ce208ff861eec76e30", null ],
    [ "_draw_signal", "d2/dcc/sdl__v_8cpp.html#ac92b66b6cc9dc668f406c1a608e5af68", null ],
    [ "_draw_threaded", "d2/dcc/sdl__v_8cpp.html#ac44f053e1e70a94bbe88cf6f973a3095", null ],
    [ "_local_palette", "d2/dcc/sdl__v_8cpp.html#a202ff6c8b1a11ccdc59df0dba543cdd5", null ],
    [ "_num_dirty_rects", "d2/dcc/sdl__v_8cpp.html#a1f9389b682678b0bed1eb3763ba164eb", null ],
    [ "_requested_hwpalette", "d2/dcc/sdl__v_8cpp.html#a311728b0d04dd857a5ffe58e9b830f98", null ],
    [ "_sdl_realscreen", "d2/dcc/sdl__v_8cpp.html#a9d1993f5034604c0523dd4552b7428dd", null ],
    [ "_sdl_surface", "d2/dcc/sdl__v_8cpp.html#aff96ee96b2be032a697feb0cc57f65cc", null ],
    [ "_use_hwpalette", "d2/dcc/sdl__v_8cpp.html#a4cfdca600f2c56e6eb8dbdc60996374e", null ],
    [ "_vk_mapping", "d2/dcc/sdl__v_8cpp.html#aaa6910b0fdef2ce9c5578cba4112f711", null ],
    [ "iFVideoDriver_SDL", "d2/dcc/sdl__v_8cpp.html#a343bfdc6c576594d2d2bcac975def6ab", null ]
];
